/***********************************************************************************************************************************
GCS Storage File Write
***********************************************************************************************************************************/
#ifndef STORAGE_GCS_WRITE_H
#define STORAGE_GCS_WRITE_H

#include "storage/gcs/storage.intern.h"
#include "storage/write.h"

/***********************************************************************************************************************************
Constructors
***********************************************************************************************************************************/
FN_EXTERN StorageWrite *storageWriteGcsNew(StorageGcs *storage, const String *name, size_t chunkSize);

#endif
